am f15a2837: Use REDIAL instead of CALL BACK for outgoing calls

* commit 'f15a2837370b0852dffb464843f3f020ebffa94b':
  Use REDIAL instead of CALL BACK for outgoing calls
diff --git a/res/values/strings.xml b/res/values/strings.xml
index b645f27..8c36ec7 100644
--- a/res/values/strings.xml
+++ b/res/values/strings.xml
@@ -549,7 +549,7 @@
          is used to describe the action of calling a phone number. Tapping causes a call to be
          placed to the number represented by the call log entry.
          [CHAR LIMIT=30] -->
-    <string name="call_log_action_redial">CALL</string>
+    <string name="call_log_action_call">CALL</string>
 
     <!-- BUTTON text for the "redial" button displayed underneath an entry in the call log. This
          is used to describe the action of calling a phone number that the user previously made an
diff --git a/src/com/android/dialer/calllog/CallLogAdapter.java b/src/com/android/dialer/calllog/CallLogAdapter.java
index 99bf386..9528e45 100644
--- a/src/com/android/dialer/calllog/CallLogAdapter.java
+++ b/src/com/android/dialer/calllog/CallLogAdapter.java
@@ -982,7 +982,8 @@
     }
 
     /***
      * Binds click handlers and intents to the voicemail, details and callback action buttons.
      *
      * @param views  The call log item views.
      */
@@ -1005,6 +1006,14 @@
             }
             views.callBackButtonView.setVisibility(View.VISIBLE);
             views.callBackButtonView.setOnClickListener(mActionListener);
+
+            final int titleId;
+            if (views.callType == Calls.VOICEMAIL_TYPE || views.callType == Calls.OUTGOING_TYPE) {
+                titleId = R.string.call_log_action_redial;
+            } else {
+                titleId = R.string.call_log_action_call_back;
+            }
+            views.callBackButtonView.setText(mContext.getString(titleId));
         } else {
             // Number is not callable, so hide button.
             views.callBackButtonView.setTag(null);
@@ -982,7 +982,8 @@
 
     /***
-     * Binds click handlers and intents to the voicemail, details and callback action buttons.
+     * Binds text titles, click handlers and intents to the voicemail, details and callback action
+     * buttons.
      *
      * @param views  The call log item views.